@@ -429,11 +429,11 @@ def versions(
         name=name,
     )
     path = _path(artifact_url)
-    if not path.exists():
-        versions = []
-    else:
+    try:
         versions = [os.path.basename(str(p)) for p in path if p.is_dir]
         versions = [v for v in versions if audeer.is_semantic_version(v)]
+    except (FileNotFoundError, RuntimeError):
+        versions = []
     return audeer.sort_versions(versions)
 
 
